DefaultManagedAgentRuntime

Struct DefaultManagedAgentRuntime 

pub struct DefaultManagedAgentRuntime { /* private fields */ }
Default implementation of the managed agent runtime.

Composed from a ModelResolver + a pluggable SessionService + optional sandbox factory and memory service. Has no platform dependencies — the platform injects its own implementations of these traits.

Fields

  • model_resolver — resolves ModelRef into Arc<dyn Llm>
  • session_service — persistent session storage backend
  • sandbox_factory — optional sandbox for built-in tool execution
  • memory — optional cross-session memory service
  • sessions — active session registry

Example

use std::sync::Arc;
use adk_managed::default_runtime::DefaultManagedAgentRuntime;
use adk_managed::resolver::DefaultModelResolver;
use adk_session::InMemorySessionService;

// Minimal runtime with defaults
let runtime = DefaultManagedAgentRuntime::new(
    Arc::new(DefaultModelResolver::new()),
    Arc::new(InMemorySessionService::new()),
);

// With sandbox and memory (feature-gated)
let runtime = DefaultManagedAgentRuntime::new(
    Arc::new(DefaultModelResolver::new()),
    Arc::new(InMemorySessionService::new()),
)
.with_sandbox(my_sandbox)
.with_memory(my_memory_service);

Implementations

Source

impl DefaultManagedAgentRuntime

pub fn new( model_resolver: Arc<dyn ModelResolver>, session_service: Arc<dyn SessionService>, ) -> Self

Create a new DefaultManagedAgentRuntime with injected services.

Arguments
  • model_resolver - Resolves ModelRef declarations into callable LLM instances.
  • session_service - Persistent storage backend for sessions and checkpoints.

Use .with_sandbox() and .with_memory() builder methods to inject optional sandbox and memory services (feature-gated).

Example
use std::sync::Arc;
use adk_managed::default_runtime::DefaultManagedAgentRuntime;
use adk_managed::resolver::DefaultModelResolver;
use adk_session::InMemorySessionService;

let runtime = DefaultManagedAgentRuntime::new(
    Arc::new(DefaultModelResolver::new()),
    Arc::new(InMemorySessionService::new()),
);
pub fn model_resolver(&self) -> &Arc<dyn ModelResolver>

Get a reference to the model resolver.

pub fn session_service(&self) -> &Arc<dyn SessionService>

Get a reference to the session service.