pub struct SessionHandle(pub String);Expand description
Opaque session handle.
Identifies an active or archived session within the runtime. The inner string is an implementation detail assigned by the runtime on session creation.
Example
use adk_managed::runtime::SessionHandle;
let handle = SessionHandle("session_xyz789".to_string());
assert_eq!(handle.0, "session_xyz789");Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for SessionHandle
impl Clone for SessionHandle
Sourcefn clone(&self) -> SessionHandle
fn clone(&self) -> SessionHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionHandle
impl Debug for SessionHandle
impl Eq for SessionHandle
Sourceimpl Hash for SessionHandle
impl Hash for SessionHandle
Sourceimpl PartialEq for SessionHandle
impl PartialEq for SessionHandle
Sourcefn eq(&self, other: &SessionHandle) -> bool
fn eq(&self, other: &SessionHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SessionHandle